==> website-php-v.1.0.81.zip: lang/fr/wsp-admin/all.inc.php <==
<?php
	define("ADMIN", "Administration"); 
	define("CONFIG", "Configuration"); 
	define("TEMPLATE", "Template"); 
	define("THEME", "Theme"); 

	define("CONFIGURE_SITE", "Configurer le site");
	define("CONFIGURE_DATABASE", "Configurer base mysql");
	define("CONFIGURE_CSS", "Configurer styles CSS");
	define("CONFIGURE_SMTP", "Configurer envoi email");
	
	define("LANGUAGE", "Langues");
	define("ENGLISH", "Anglais");
	define("FRENCH", "Franais");
	
	define("DISCONNECT", "Dconnexion");
	define("CHANGE_PASSWD", "Changer de mot de passe");
	define("CHANGE_PASSWD_CONGRATULATION", "Flicitations, votre mot de passe a t chang.");
	define("CHANGE_PASSWD_ERROR", "Erreur, vrifiez que votre nouveau mot de passe n'est pas vide ou que votre ancien mot de passe est correct.");
	
	define("NEW_WSP_VERSION", "Vous pouvez <a href=\"http://www.website-php.com/download.html\" target=\"_blank\">tlcharger la dernire version de Website-PHP</a> (version %s).<br/>");
	define("NEW_BROWSCAP_VERSION", "Browscap.ini n'est pas  jour, <a href=\"javascript:void(0);\" onClick=\"%s\">cliquez ici pour le mettre  jour</a> (version %s).<br/>");
	define("CURRENT_WSP_VERSION", "Version actuelle de Website-PHP: %s");
	define("INSTALL_PHP_SOAP", "Installez la librairie PHP SOAP pour tre alert des nouvelles version de <a href=\"http://www.website-php.com\" target=\"_blank\">WebSite-PHP</a><br/>");
	
	define("UPDATE_FRAMEWORK", "Mise  jour");
	define("UPDATE_FRAMEWORK_WAITING", "Veuillez patienter ...");
	define("UPDATE_FRAMEWORK_COMPLETE", "Mise  jour termine");
	define("UPDATE_FRAMEWORK_COMPLETE_OK", "Flicitation, %s a bien t mis  jour");
	
	define("PAGE_IN_CONSTRUCTION", "Page en construction, <a href=\"http://www.website-php.com/contact.html\">contactez nous</a> si vous avez des suggestions ou vu des erreurs.");
?>

==> website-php-v.1.0.85.zip: lang/fr/wsp-admin/all.inc.php <==
<?php
	define("ADMIN", "Administration"); 
	define("CONFIG", "Configuration"); 
	define("TEMPLATE", "Template"); 
	define("THEME", "Theme"); 

	define("CONFIGURE_SITE", "Configurer le site");
	define("CONFIGURE_DATABASE", "Configurer base mysql");
	define("CONFIGURE_CSS", "Configurer styles CSS");
	define("CONFIGURE_SMTP", "Configurer envoi email");
	define("CONFIGURE_USERS", "Configurer utilisateurs");
	define("CONFIGURE_MODULES", "Configurer modules");
	
	define("LANGUAGE", "Langues");
	define("ENGLISH", "Anglais");
	define("FRENCH", "Franais");
	
	define("DISCONNECT", "Dconnexion");
	define("CHANGE_PASSWD", "Changer de mot de passe");
	define("CHANGE_PASSWD_CONGRATULATION", "Flicitations, votre mot de passe a t chang.");
	define("CHANGE_PASSWD_ERROR", "Erreur, vrifiez que votre nouveau mot de passe n'est pas vide ou que votre ancien mot de passe est correct.");
	
	define("NEW_WSP_VERSION", "Vous pouvez <a href=\"javascript:void(0);\" onClick=\"%s\">mettre  jour Website-PHP  la dernire version</a> (version %s).<br/>");
	define("NEW_BROWSCAP_VERSION", "Browscap.ini n'est pas  jour, <a href=\"javascript:void(0);\" onClick=\"%s\">cliquez ici pour le mettre  jour</a> (version %s).<br/>");
	define("CURRENT_WSP_VERSION", "Version actuelle de Website-PHP: %s");
	define("INSTALL_PHP_SOAP", "Installez la librairie PHP SOAP pour tre alert des nouvelles version de <a href=\"http://www.website-php.com\" target=\"_blank\">WebSite-PHP</a><br/>");
	
	define("UPDATE_FRAMEWORK", "Mise  jour");
	define("UPDATE_FRAMEWORK_WAITING", "Veuillez patienter ...");
	define("UPDATE_FRAMEWORK_COMPLETE", "Mise  jour termine");
	define("UPDATE_FRAMEWORK_COMPLETE_OK", "Flicitation, %s a bien t mis  jour");
	define("UPDATE_FRAMEWORK_COMPLETE_NOT_OK", "Erreur, %s n'est pas  jour");
	define("UPDATE_FRAMEWORK_CONFIRM", "tes vous sr de vouloir mettre  jour %s ?");
	define("UPDATE_FRAMEWORK_WSP_WARNING", "Attention, cette mise  jour peut avoir des impacts sur la version actuelle de votre site. Nous vous recommandons de sauvegarder de votre site (CVS, SVN, ...) et de ne pas faire cette mise a jour en production.");
	define("UPDATE_FRAMEWORK_YES", "Oui");
	define("UPDATE_FRAMEWORK_NO", "Non");
	
	define("PAGE_IN_CONSTRUCTION", "Page en construction, <a href=\"http://www.website-php.com/contact.html\">contactez nous</a> si vous avez des suggestions ou vu des erreurs.");
?>
